@@ -84,3 +84,56 @@ _line_to_array(
     return unique_col_i;
 }
 
+long
+_line_to_array(
+    const long * cols, const long * unique_cols, 
+    long num_cols, long max_col,
+    char delimit, int skip_init_space,
+    const char * c, long len, 
+    parsed_t parsed[max_num_cols])
+{
+    DBG_VERIFY(len >= 0);
+    long unique_col_i = 0, col_i = 0, in_col_i = 0;
+    bool should_parse = _should_parse(unique_cols, 0, 0);
+    while (len--) {
+        if (*c == delimit){
+            if (!add_field(should_parse, c, in_col_i, parsed, unique_col_i))
+                return -1;
+            ++col_i;
+            if(cols != NULL && col_i > max_col)
+                break;
+            should_parse = _should_parse(unique_cols, unique_col_i, col_i);
+            in_col_i = 0;
+            ++c; 
+            continue;
+        }
+
+        if (*c == '\n' || *c == '\r'){
+            break;
+        }
+
+        if (!should_parse) {
+            ++c;
+            continue;
+        }
+    
+        if (*c == ' ' && in_col_i == 0 && skip_init_space) {
+            ++c; 
+            continue;
+        }
+
+        ++in_col_i;
+        if (in_col_i == max_field_len) {
+            PyErr_Format(PyExc_IndexError, "Max col length exceeded");
+            return -1;
+        }
+
+        ++c; 
+    }
+    
+    if (!add_field(should_parse, c, in_col_i, parsed, unique_col_i))
+        return -1;
+
+    return unique_col_i;
+}
+
