@@ -7,6 +7,7 @@ import itertools
 
 from dagpype._core import sinks
 import dagpype_c
+_has_c_line_writer = 'line_writer' in dir(dagpype_c)
 
 
 __all__ = []
@@ -64,7 +65,8 @@ def to_stream(stream, names = None, delimit = b',', line_terminator = b'\n', buf
                     return
                 self._n += len(stored)
                 self._stream_.write(
-                    line_terminator + line_terminator.join(stored) if not self._first else line_terminator.join(stored))
+                    line_terminator + line_terminator.join(stored) if not self._first else \
+                        line_terminator.join(stored))
                 self._first = False
             
             def close(self):
@@ -84,7 +86,10 @@ def to_stream(stream, names = None, delimit = b',', line_terminator = b'\n', buf
             stream_.write((_stringify_tup(names) if isinstance(names, tuple) else names) + line_terminator)
             stream_.flush()
             
-        writer = _LineWriter(stream_, line_terminator, dagpype_c.line_writer(stream_.fileno(), line_terminator))     
+        writer = _LineWriter(
+            stream_, 
+            line_terminator, 
+            dagpype_c.line_writer(stream_.fileno(), line_terminator) if _has_c_line_writer else None)     
         
         stored = []
         try:
@@ -399,13 +404,13 @@ def corr():
 
     @sinks
     def _dagpype_internal_fn_act(target):
-        c = dagpype_c.correlator()
+        c = dagpype_c.Correlator()
         try:
             while True:
                 x, y = (yield)
-                dagpype_c.correlator_push(c, float(x), float(y))
+                c.push(float(x), float(y))
         except GeneratorExit:
-            target.send(dagpype_c.correlator_corr(c))
+            target.send(c.corr())
             target.close()
     return _dagpype_internal_fn_act
 
