@@ -1,10 +1,9 @@
 #ifndef ARRAY_COL_READER_HPP
 #define ARRAY_COL_READER_HPP
 
-#include "parser_defs.hpp"
+#include <Python.h>
 
-extern "C" PyObject *
-array_col_reader(PyObject *module, PyObject *args, PyObject *keyword_args);
+#include "parser_defs.hpp"
 
 extern PyTypeObject ArrayColReaderType;
 
