@@ -1,9 +1,9 @@
-#include <iostream>
-
 #include <Python.h>
 #include <structmember.h>
 #include <numpy/arrayobject.h>
 
+#include <iostream>
+
 #include "defs.hpp"
 #include "enumerator.hpp"
 
@@ -18,24 +18,16 @@ struct Enumerator
 
 extern PyTypeObject EnumeratorType;
 
-extern "C" int
-enumerator_traverse(Enumerator * self, visitproc visit, void *arg)
-{
-    return 0;
-}
-
 extern "C" void
 enumerator_dealloc(Enumerator * self)
 {
-    PyObject_GC_UnTrack(self);
-
-    PyObject_GC_Del(self);
+    Py_TYPE(self)->tp_free((PyObject*)self);
 }
 
 extern "C" PyObject *
-enumerator(PyObject *module, PyObject *args, PyObject *keyword_args)
+enumerator_new(PyTypeObject * type, PyObject * args, PyObject * keyword_args)
 {
-    Enumerator * const self = PyObject_GC_New(Enumerator, &EnumeratorType);
+    Enumerator * const self = (Enumerator *)type->tp_alloc(type, 0);
     if (self == NULL) {
         PyErr_NoMemory();
         return NULL;
@@ -49,28 +41,17 @@ enumerator(PyObject *module, PyObject *args, PyObject *keyword_args)
         return NULL;
     }
 
-    PyObject_GC_Track(self);
     return (PyObject *)self;
 }
 
-extern "C" int
-enumerator_clear(Enumerator * self)
-{
-    self->count = 0;
-
-    return 0;
-}
-
 extern "C" PyObject *
-enumerator_next(PyObject *module, PyObject *args, PyObject *keyword_args)
+enumerator_next(Enumerator * self, PyObject * args, PyObject * keyword_args)
 {
-    Enumerator * self;
     PyObject * o;
     if (!PyArg_ParseTuple(
             args, 
-            "OO",
-            reinterpret_cast<PyObject **>(&self), 
-            &o) || self == NULL || o == NULL) {
+            "O",
+            &o) || o == NULL) {
         PyErr_SetString(PyExc_TypeError, "Failed to parse stuff");
         return NULL;
     }
@@ -99,6 +80,7 @@ enumerator_next(PyObject *module, PyObject *args, PyObject *keyword_args)
 }
 
 static PyMethodDef enumerator_methods[] = {
+    { "next", (PyCFunction)enumerator_next, METH_VARARGS, "" },
     { NULL}
 };
 
@@ -110,16 +92,16 @@ PyDoc_STRVAR(EnumeratorType_doc, "");
 
 PyTypeObject EnumeratorType = {
     PyVarObject_HEAD_INIT(NULL, 0)
-    "dagpype_c.enumerator",               /*tp_name*/
+    "dagpype_c.Enumerator",               /*tp_name*/
     sizeof(Enumerator),                   /*tp_basicsize*/
     0,                                      /*tp_itemsize*/
     /* methods */
     (destructor)enumerator_dealloc,          /*tp_dealloc*/
-    0,                           /*tp_print*/
-    0,                         /*tp_getattr*/
-    0,                         /*tp_setattr*/
-    0,                             /*tp_compare*/
-    0,                            /*tp_repr*/
+    0,                                         /*tp_print*/
+    0,                                         /*tp_getattr*/
+    0,                                         /*tp_setattr*/
+    0,                                          /*tp_compare*/
+    0,                                        /*tp_repr*/
     0,                                      /*tp_as_number*/
     0,                                      /*tp_as_sequence*/
     0,                                      /*tp_as_mapping*/
@@ -129,17 +111,23 @@ PyTypeObject EnumeratorType = {
     0,                                      /*tp_getattro*/
     0,                                      /*tp_setattro*/
     0,                                      /*tp_as_buffer*/
-    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE | 
-    Py_TPFLAGS_HAVE_GC,                     /*tp_flags*/
+    Py_TPFLAGS_DEFAULT ,                     /*tp_flags*/
     EnumeratorType_doc,                     /*tp_doc*/
-    (traverseproc)enumerator_traverse,       /*tp_traverse*/
-    (inquiry)enumerator_clear,               /*tp_clear*/
+    0,       /*tp_traverse*/
+    0,               /*tp_clear*/
     0,                                      /*tp_richcompare*/
     0,                                      /*tp_weaklistoffset*/
     0,                      /*tp_iter*/
     0,                              /*tp_iternext*/
     enumerator_methods,                      /*tp_methods*/
     enumerator_memberlist,                   /*tp_members*/
-    0,                                      /*tp_getset*/
+    0,                       /* tp_getset */
+    0,                       /* tp_base */
+    0,                       /* tp_dict */
+    0,                       /* tp_descr_get */
+    0,                       /* tp_descr_set */
+    0,                       /* tp_dictoffset */
+    0,      /* tp_init */
+    0,                         /* tp_alloc */
+    enumerator_new,                 /* tp_new */
 };
-
