@@ -245,7 +245,7 @@ def exp_ave(alpha):
     def _dagpype_internal_fn_act(target):
         assert 0 <= alpha <= 1
 
-        av = dagpype_c.exp_averager(alpha)
+        av = dagpype_c.ExpAverager(alpha)
 
         proto = numpy.array([1])
         try:
@@ -254,7 +254,7 @@ def exp_ave(alpha):
                 assert type(e) == type(proto)
                 assert len(e.shape) == 1
                 r = e.copy()
-                dagpype_c.exp_averager_ave(av, e, r)
+                av.ave(e, r)
                 target.send(r)
         except GeneratorExit:
             target.close()
