@@ -8,6 +8,7 @@ import collections
 import re
 import itertools
 import string
+import math
 
 sys.path.extend(['..', '../dagpype'])
 from dagpype import *
@@ -369,6 +370,18 @@ class _TestSeq02CSV(unittest.TestCase):
                 f.write('\t'.join([str(random.random()) for i in range(100)]) + '\n')
         c = stream_vals('tmp.tsv', delimit = b'\t') | count()
         self.assertEqual(c, 10)
+        
+    def test_29(self):
+        l = stream_vals('data/ieee_bad_data.csv', cols = b'day') | to_list()
+        self.assertTrue(math.isnan(l[0]))
+        self.assertEqual(l[1: ], [1., 2.])        
+        l = stream_vals('data/ieee_bad_data.csv', cols = b'wind') | to_list()
+        self.assertEqual(l, [2., 4., 7.])        
+        l = stream_vals('data/ieee_bad_data.csv', cols = b'hail') | to_list()
+        self.assertTrue(math.isinf(-l[1]))
+        l = stream_vals('data/ieee_bad_data.csv', cols = b'rain') | to_list()
+        self.assertTrue(math.isinf(-l[0]))
+        self.assertTrue(math.isnan(l[2]))
 
 
 class _TestSeq03Control(unittest.TestCase):
